==> haskell-hspec-megaparsec-2.2.1-95-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-megaparsec
version:              2.2.1
visibility:           public
id:                   hspec-megaparsec-2.2.1-EQaExLLl59RJB8qUEEy6ka
key:                  hspec-megaparsec-2.2.1-EQaExLLl59RJB8qUEEy6ka
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/hspec-megaparsec
synopsis:             Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.

category:             Testing, Parsing
abi:                  544311f91577f397648d318c5cc47842
exposed:              True
exposed-modules:      Test.Hspec.Megaparsec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-megaparsec-2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-megaparsec-2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-megaparsec-2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-megaparsec
hs-libraries:         HShspec-megaparsec-2.2.1-EQaExLLl59RJB8qUEEy6ka
depends:
    base-4.17.2.1 hspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568
    megaparsec-9.7.0-L0csM5p3V1T7HhcnanYAK3

haddock-interfaces:
    /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-megaparsec-2.2.1-96-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-megaparsec
version:              2.2.1
visibility:           public
id:                   hspec-megaparsec-2.2.1-819N1F3ycXFDA1K6vB5Nod
key:                  hspec-megaparsec-2.2.1-819N1F3ycXFDA1K6vB5Nod
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/hspec-megaparsec
synopsis:             Utility functions for testing Megaparsec parsers with Hspec
description:
    Utility functions for testing Megaparsec parsers with Hspec.

category:             Testing, Parsing
abi:                  a281d56cfede06e2c15356995b298673
exposed:              True
exposed-modules:      Test.Hspec.Megaparsec
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-megaparsec-2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-megaparsec-2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-megaparsec-2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-megaparsec
hs-libraries:         HShspec-megaparsec-2.2.1-819N1F3ycXFDA1K6vB5Nod
depends:
    base-4.17.2.1 hspec-expectations-0.8.3-ByiC9PUirWlDy5uDUGE568
    megaparsec-9.7.0-CvA3wDhViq5BjXD55Lo9fs

haddock-interfaces:
    /usr/share/doc/haskell-hspec-megaparsec/html/hspec-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-hspec-megaparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
